require("colors");
var util = require("util");

var unit;

function assert(pass, message){
    console.log(
        ((pass? "✓" : "×").bold+" "+unit+":\t"+message)[pass? "green" : "red"]
    )
}

function eq( result, expected, msg ){
    var pass = result === expected;
    assert(
        pass,
        pass? msg : msg+"diff:"+diffString(result, expected)
    )
}

var facade = require("../src");

unit = "Parsing";

var fragments = {
    //Normal element
    "<b>asdf</b>": "<b>asdf</b>",
    
    //Element left open
    "<b>asdf": "<b>asdf</b>",
    
    //Empty element
    "<br>a": "<br />a",
    
    //Text before
    "a <strong>a</strong>": "a <strong>a</strong>",
    
    //Text after
    "<strong>a</strong> a": "<strong>a</strong> a",
    
    //Both
    "a <strong>a</strong> a": "a <strong>a</strong> a",
    
    //Double quoted attribute
    '<div foo="bar" />':'<div foo=bar />',
    
    //Single quoted attribute
    "<div foo='bar' />":'<div foo=bar />',
    
    //Non-quoted attribute
    '<div foo=bar />':'<div foo=bar />'
    
},x;


for(x in fragments){
    eq(
        facade(x).render(), fragments[x], x
    )
}

unit = "Selection";
var document = facade("<div>\
<span class='foo bar'>Hi</span>\
<b class='foo'>Hello World!</b>\
<b id='test'>Hola</b>\
<strong>Hola</strong>\
<em foo=bar>Hi</em>\
<strong foo=baz>Hi</strong>\
<var foo=fez>Fezzes are cool</var>\
<div>\
<span>\
<var>Hi</var>\
</span>\
</div>\
</div>\
<var>a</var>")



var selectors = {
    "b": "<b class=foo>Hello World!</b><b id=test>Hola</b>",
    "#test": "<b id=test>Hola</b>",
    "b#test": "<b id=test>Hola</b>",
    "em#test": "",
    ".foo": "<span class='foo bar'>Hi</span><b class=foo>Hello World!</b>",
    ".foo.bar": "<span class='foo bar'>Hi</span>",
    ".baz": "",
    "[foo=bar]":"<em foo=bar>Hi</em>",
    "[foo^=ba]":"<em foo=bar>Hi</em><strong foo=baz>Hi</strong>",
    "[foo$=z]": "<strong foo=baz>Hi</strong><var foo=fez>Fezzes are cool</var>",
    "[foo*=a]": "<em foo=bar>Hi</em><strong foo=baz>Hi</strong>",
    "strong, var":"<strong>Hola</strong><strong foo=baz>Hi</strong><var foo=fez>Fezzes are cool</var><var>Hi</var><var>a</var>",
    "div var":"<var foo=fez>Fezzes are cool</var><var>Hi</var>",
    "div>var":"<var foo=fez>Fezzes are cool</var>",
    "em+strong":"<strong foo=baz>Hi</strong>",
    "strong~strong":"<strong foo=baz>Hi</strong>",
    "var:first-child":"<var>Hi</var>",
    "span:nth-child(odd)":"<span class='foo bar'>Hi</span><span><var>Hi</var></span>",
    "b:nth-child(even)":"<b class=foo>Hello World!</b>",
    "var:last-child":"<var>Hi</var><var>a</var>",
    "div>*":"<span class='foo bar'>Hi</span><b class=foo>Hello World!</b><b id=test>Hola</b><strong>Hola</strong><em foo=bar>Hi</em><strong foo=baz>Hi</strong><var foo=fez>Fezzes are cool</var><div><span><var>Hi</var></span></div>"
}

for(x in selectors){
    eq(
        document.find(x).render(),
        selectors[x],
        x
    )
}


unit = "Manipulation";

eq(
    facade("<div><b>Hi</b></div>").replace("b", "<strong>Hola</strong>").render(),
    "<div><strong>Hola</strong></div>",
    "replace"
)